# Suite numérique et leurs convergences

Une **Suite** est une collection de nombres **Infinie** et **Ordonée** de nombres réels.
    - **Infinie**: Ne s'arrete pas
    - **Ordonée**: La place des nombres dans la suite est importante

Nous cherchons à savoir quelle est la valeur de l'élément situé à une position donnée

## Fonctions

On parle alors de fonction pour définir une suite:

\\[
    n \mapsto x_n
\\]
où n est l'indice (\\(\in\mathbb{N}\\)) et \\(x_n\\) est l'élément (\\(\in\mathbb{R}\\))

### Rappel

Une [fonction](../logique/fonctions.md) est une relation qui à chaques éléments de A fait corespondre **au plus, un** élément de B
\\[
    f: \mathbb{R} \to \mathbb{R}: x\mapsto y = x^2
\\]

**Atention, A n'est pas forcément le domaine** mais \\(f \subseteq A\\) Toujours

### Le domaine d'une suite

Pour trouver le domaine d'une suite, Nous pouvons chercher ses conditions d'éxistences.
Si ces conditions permettent une suite **infinie** On cherche la valeur ordonnée de départ et le domaine est noté comme suit

- Une **suite** est une fonction tel que
    - \\(I \to \mathbb{R}: n \mapsto x_n \text{ où } I = \mathbb{N}^{\geq k} \text{ où } k\in \mathbb{N}\\)

## Notation

le terme générale d'une suite est noté
\\[
    \Large{(x_n)_{n \in \mathbb{N}^{\geq k}} \subseteq \mathbb{R}}
\\]

Il n'est pas toujours possible de trouver une formule pour une suite (i.e.: suite de nombre premiers)

On peut aussi définir une suite par récurence.
\\[
    (x_n) _{n \in \mathbb{N}} \quad \begin{cases} &x_0=3 \\\\ &\forall n \in\mathbb{N}\quad x _{n+1}= x_n + 4  \end{cases}
\\]

C'est une suite arithmétique de raison 4 (Pour passer à l'élément suivant on ajoute 4)

- Une **suite arithmétique** \\((x_n)_{n\in \mathbb{N}}\\) est définie par:
    - \\(\begin{cases} x_0 \in \mathbb{R} \\\\ \forall n \in \mathbb{N} \quad  x_{n + 1} = x_n + r \end{cases}\\)
        - r est la raison

\\[ \forall n \in \mathbb{N} \quad  x_n = x_0 + n * r \\]

- Une **suite géométrique** \\((x_n)_{n\in \mathbb{N}}\\) est définie par:
    - \\(\begin{cases} x_0 \in \mathbb{R} \\\\ \forall n \in \mathbb{N} \quad  x_{n + 1} = qx_n \end{cases}\\)
        - q est la raison

\\[ \forall n \in \mathbb{N} \quad  x_n = x_0 * q^n \\]

## Convergence 

1) \\((x_n)\\) converge vers un réel a si \\(x_n\\) est proche de a lorsque n devient grand
2) La distance entre \\(x_n\\) et a est de plus en plus petite (peut contenir l'élément vers lequel il converge (ex: \\((0)_{n \in \mathbb{N}}\\))
3) Une suite \\((x_n)\\) converge vers un réel a si la distance entre \\(x_n \text{ et } a\\) peut être rendue aussi petite que je le veux.
    - Donc \\(d(x_n, a) = |x_n - a| \leq \varepsilon, \varepsilon \in \mathbb{R}\\)

- **Unicitée de la limite**:
    - Soient \\((x_n) \subseteq \mathbb{R} \text{ et } a_1, a_2 \in \mathbb{R}\\)
        - Si \\((x_n)\\) converge à la fois vers \\(a_1 \text{ et vers } a_2 \text{ alors } a_1 = a_2\\)

### Notation

Pour exprimer que \\((x_n)\\) converge vers a:
\\[
    x_n \xrightarrow[n \to +\infty]{} a \quad \text{ Ou } \quad \lim_{n \to +\infty}x_n = a 
\\]

### Regles de calculs

1) La suite de constante \\(a \in \mathbb{R}\\), noté \\((a)_{n \in \mathbb{N}}\\) converge vers a
2) \\((\frac{1}{n^P}) \xrightarrow[n \to +\infty]{} 0 \text{ si } P > 0\\)
3) \\((a^n) \xrightarrow[n \to +\infty]{} 0 \text{ si } a \in ]-1,1[\\)

- Soient \\(a, b \in \mathbb{R}\\) et \\((x_n), (y_n)\\) deux suites de réels.
    - On suppose que \\(\lim\limits_{n \to \infty} x_n = a \\)
    - On suppose que \\(\lim\limits_{n \to \infty} y_n = b \\)
        1) \\(\lim\limits_{n \to \infty}x_n + y_n = a + b\\)
        2) \\(\lim\limits_{n \to \infty}x_n * y_n = a * b\\)
        3) \\(\lim\limits_{n \to \infty}\frac{x_n}{y_n} = \frac{a}{b}\\)

## Comparaison des suites

### Théorem de la convergence dominée

Pour se faire nous avons besoin d'une intuition pour a

- Soient \\((x_n), (y_n) \subseteq \mathbb{R}, a \in \mathbb{R} \\)
    1) Si \\((y_n) \xrightarrow[n \to +\infty]{} 0\\)
    2) Si \\(\forall n, |x_n - a| \leq y_n\\)
        - Alors \\(x_n \xrightarrow[x \to +\infty]{} a\\)

### Théorem du Sandwich

- Soient \\((x_n), (y_n), (z_n) \subseteq \mathbb{R}, a \in \mathbb{R} \\)
    1) Si \\((y_n) \xrightarrow[n \to +\infty]{} a \text{ et } (z_n) \xrightarrow[n \to +\infty]{} a\\)
    2) Si \\(\forall n, y_n \leq x_n \leq z_n\\)
        - Alors \\(x_n \xrightarrow[x \to +\infty]{} a\\)

